@@ -50,9 +50,7 @@
 #'
 ols_plot_dffits <- function(model) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
+  check_model(model)
 
   dbetas <- NULL
   obs    <- NULL
