@@ -40,9 +40,7 @@
 #'
 ols_plot_resid_stud_fit <- function(model) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
+  check_model(model)
 
   fct_color <- NULL
   color     <- NULL
