@@ -23,9 +23,7 @@
 #'
 ols_plot_hadi <- function(model) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
+  check_model(model)
 
   hadi <- NULL
 
