@@ -23,10 +23,7 @@
 #'
 ols_test_correlation <- function(model) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
-
+  check_model(model)
   corrout(model)
 
 }
