@@ -22,9 +22,7 @@
 #'
 ols_plot_resid_pot <- function(model) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
+  check_model(model)
 
   res <- NULL
   pot <- NULL
