@@ -19,9 +19,7 @@
 #'
 ols_plot_resid_qq <- function(model) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
+  check_model(model)
 
   resid <- residuals(model)
   y     <- quantile(resid[!is.na(resid)], c(0.25, 0.75))
