@@ -20,9 +20,7 @@
 #'
 ols_plot_resid_lev <- function(model) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
+  check_model(model)
 
   lev_thrsh <- NULL
   fct_color <- NULL
