@@ -31,18 +31,14 @@
 #' \code{ols_stepaic_backward()} has been deprecated. Instead use \code{ols_step_backward_aic()}.
 #'
 #' @examples
-#' \dontrun{
 #' # stepwise backward regression
 #' model <- lm(y ~ ., data = surgical)
 #' ols_step_backward_aic(model)
-#' }
 #'
-#' \dontrun{
 #' # stepwise backward regression plot
 #' model <- lm(y ~ ., data = surgical)
 #' k <- ols_step_backward_aic(model)
 #' plot(k)
-#' }
 #'
 #' @importFrom ggplot2 geom_text
 #' @importFrom rlang prepend
@@ -59,17 +55,9 @@ ols_step_backward_aic <- function(model, ...) UseMethod("ols_step_backward_aic")
 #'
 ols_step_backward_aic.default <- function(model, details = FALSE, ...) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
-
-  if (!is.logical(details)) {
-    stop("details must be either TRUE or FALSE", call. = FALSE)
-  }
-
-  if (length(model$coefficients) < 3) {
-    stop("Please specify a model with at least 2 predictors.", call. = FALSE)
-  }
+  check_model(model)
+  check_logic(details)
+  check_npredictors(model, 3)
 
   response <-
     model %>%
