@@ -36,18 +36,14 @@
 #' \code{ols_step_backward()} has been deprecated. Instead use \code{ols_step_backward_p()}.
 #'
 #' @examples
-#' \dontrun{
 #' # stepwise backward regression
 #' model <- lm(y ~ ., data = surgical)
 #' ols_step_backward_p(model)
-#' }
 #'
-#' \dontrun{
 #' # stepwise backward regression plot
 #' model <- lm(y ~ ., data = surgical)
 #' k <- ols_step_backward_p(model)
 #' plot(k)
-#' }
 #'
 #' @family variable selection procedures
 #'
@@ -59,24 +55,14 @@ ols_step_backward_p <- function(model, ...) UseMethod("ols_step_backward_p")
 #' @rdname ols_step_backward_p
 #'
 ols_step_backward_p.default <- function(model, prem = 0.3, details = FALSE, ...) {
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS regression model.", call. = FALSE)
-  }
-
-  if ((prem < 0) | (prem > 1)) {
-    stop("p value for removing variables from the model must be between 0 and 1.", call. = FALSE)
-  }
-
-  if (!is.logical(details)) {
-    stop("details must be either TRUE or FALSE", call. = FALSE)
-  }
-
-  if (length(model$coefficients) < 3) {
-    stop("Please specify a model with at least 2 predictors.", call. = FALSE)
-  }
+  
+  check_model(model)
+  check_logic(details)
+  check_values(prem, 0, 1)
+  check_npredictors(model, 3)
 
 
-  l        <- mod_sel_data(model)
+  l        <- eval(model$call$data)
   nam      <- colnames(attr(model$terms, "factors"))
   response <- names(model$model)[1]
   preds    <- nam
@@ -110,9 +96,10 @@ ols_step_backward_p.default <- function(model, prem = 0.3, details = FALSE, ...)
   }
 
   while (!end) {
-    m <- ols_regress(paste(response, "~", paste(preds, collapse = " + ")), l)
-    pvals <- m$pvalues[-1]
-    maxp  <- which(pvals == max(pvals))
+    m <- lm(paste(response, "~", paste(preds, collapse = " + ")), l)
+    m_sum <- Anova(m)
+    pvals <- m_sum$`Pr(>F)`
+    maxp  <- which(pvals == max(pvals, na.rm = TRUE))
 
     suppressWarnings(
       if (pvals[maxp] > prem) {
