@@ -39,18 +39,14 @@
 #' \code{ols_stepwise()} has been deprecated. Instead use \code{ols_step_both_p()}.
 #'
 #' @examples
-#' \dontrun{
 #' # stepwise regression
 #' model <- lm(y ~ ., data = surgical)
 #' ols_step_both_p(model)
-#' }
 #'
-#' \dontrun{
 #' # stepwise regression plot
 #' model <- lm(y ~ ., data = surgical)
 #' k <- ols_step_both_p(model)
 #' plot(k)
-#' }
 #'
 #' @family variable selection_procedures
 #'
@@ -63,25 +59,11 @@ ols_step_both_p <- function(model, ...) UseMethod("ols_step_both_p")
 #'
 ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FALSE, ...) {
 
-  if (!all(class(model) == "lm")) {
-    stop("Please specify a OLS linear regression model.", call. = FALSE)
-  }
-
-  if ((pent < 0) | (pent > 1)) {
-    stop("p value for entering variables into the model must be between 0 and 1.", call. = FALSE)
-  }
-
-  if ((prem < 0) | (prem > 1)) {
-    stop("p value for removing variables from the model must be between 0 and 1.", call. = FALSE)
-  }
-
-  if (!is.logical(details)) {
-    stop("details must be either TRUE or FALSE", call. = FALSE)
-  }
-
-  if (length(model$coefficients) < 3) {
-    stop("Please specify a model with at least 2 predictors.", call. = FALSE)
-  }
+  check_model(model)
+  check_logic(details)
+  check_values(pent, 0, 1)
+  check_values(prem, 0, 1)
+  check_npredictors(model, 3)
 
   response <-
     model %>%
@@ -89,8 +71,8 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
     names() %>%
     extract(1)
 
-  l        <- mod_sel_data(model)
-  nam      <- coeff_names(model)
+  l        <- eval(model$call$data)
+  nam      <- colnames(attr(model$terms, "factors"))
   df       <- nrow(l) - 2
   tenter   <- qt(1 - (pent) / 2, df)
   trem     <- qt(1 - (prem) / 2, df)
@@ -107,7 +89,7 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
   pvals   <- c()
   tvals   <- c()
   step    <- 1
-  ppos    <- step + 1
+  ppos    <- step
   rsq     <- c()
   cp      <- c()
   f       <- c()
@@ -135,15 +117,17 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
 
   for (i in seq_len(mlen_p)) {
     predictors <- all_pred[i]
-    m <- ols_regress(paste(response, "~", paste(predictors, collapse = " + ")), l)
-    pvals[i] <- m$pvalues[ppos]
-    tvals[i] <- m$tvalues[ppos]
+    m <- lm(paste(response, "~", paste(predictors, collapse = " + ")), l)
+    m_sum <- Anova(m)
+    pvals[i] <- m_sum$`Pr(>F)`[ppos]
+    # pvals[i] <- m$pvalues[ppos]
+    # tvals[i] <- m$tvalues[ppos]
   }
 
-  minp    <- which(pvals == min(pvals))
-  tvals   <- abs(tvals)
-  maxt    <- which(tvals == max(tvals))
-  preds   <- all_pred[maxt]
+  minp    <- which(pvals == min(pvals, na.rm = TRUE))
+  # tvals   <- abs(tvals)
+  # maxt    <- which(tvals == max(tvals))
+  preds   <- all_pred[minp]
   lpreds  <- length(preds)
   fr      <- ols_regress(paste(response, "~",
                                paste(preds, collapse = " + ")), l)
@@ -152,6 +136,8 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
   cp      <- ols_mallows_cp(fr$model, model)
   aic     <- ols_aic(fr$model)
   sbc     <- ols_sbc(fr$model)
+
+
   sbic    <- ols_sbic(fr$model, model)
   rmse    <- sqrt(fr$ems)
   betas   <- append(betas, fr$betas)
@@ -184,30 +170,32 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
 
   while (step < mlen_p) {
 
-    all_pred <- all_pred[-maxt]
+    all_pred <- all_pred[-minp]
     len_p    <- length(all_pred)
     step     <- step + 1
-    ppos     <- ppos + length(maxt)
+    ppos     <- ppos + length(minp)
     pvals    <- c()
     tvals    <- c()
 
     for (i in seq_len(len_p)) {
 
       predictors <- c(preds, all_pred[i])
-      m          <- ols_regress(paste(response, "~",
+      m          <- lm(paste(response, "~",
                                       paste(predictors, collapse = " + ")), l)
-      pvals[i]   <- m$pvalues[ppos]
-      tvals[i]   <- m$tvalues[ppos]
+      m_sum <- Anova(m)
+      pvals[i] <- m_sum$`Pr(>F)`[ppos]
+      # pvals[i]   <- m$pvalues[ppos]
+      # tvals[i]   <- m$tvalues[ppos]
     }
 
-    minp  <- which(pvals == min(pvals))
-    tvals <- abs(tvals)
-    maxt  <- which(tvals == max(tvals))
+    minp  <- which(pvals == min(pvals, na.rm = TRUE))
+    # tvals <- abs(tvals)
+    # maxt  <- which(tvals == max(tvals))
 
-    if (tvals[maxt] >= tenter) {
+    if (pvals[minp] <= pent) {
 
-      preds     <- c(preds, all_pred[maxt])
-      var_index <- c(var_index, all_pred[maxt])
+      preds     <- c(preds, all_pred[minp])
+      var_index <- c(var_index, all_pred[minp])
       method    <- c(method, tech[1])
       lpreds    <- length(preds)
       all_step  <- all_step + 1
@@ -251,18 +239,20 @@ ols_step_both_p.default <- function(model, pent = 0.1, prem = 0.3, details = FAL
         cat("\n\n")
       }
 
-      m2      <- ols_regress(paste(response, "~",
+      m2      <- lm(paste(response, "~",
                                    paste(preds, collapse = " + ")), l)
-      tvals_r <- abs(m2$tvalues[-1])
-      mint    <- which(tvals_r == min(tvals_r))
-      if (tvals_r[mint] < trem) {
+      m2_sum <- Anova(m2)
+      # pvals[i] <- m_sum$`Pr(>F)`[ppos]
+      pvals_r <- m2_sum$`Pr(>F)`
+      maxp    <- which(pvals_r == max(pvals_r, na.rm = TRUE))
+      if (pvals_r[maxp] > prem) {
 
-        var_index <- c(var_index, preds[mint])
+        var_index <- c(var_index, preds[maxp])
         lvar      <- length(var_index)
         method    <- c(method, tech[2])
-        preds     <- preds[-mint]
+        preds     <- preds[-maxp]
         all_step  <- all_step + 1
-        ppos      <- ppos - length(mint)
+        ppos      <- ppos - length(maxp)
         fr        <- ols_regress(paste(response, "~",
                                        paste(preds, collapse = " + ")), l)
         rsq       <- c(rsq, fr$rsq)
