@@ -13,19 +13,19 @@ ols_regress(mpg ~ disp + hp + wt + qsec, data = mtcars)
 
 ## ----rvsfplot, fig.width=5, fig.height=5, fig.align='center'-------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-ols_rvsp_plot(model)
+ols_plot_resid_fit(model)
 
-## ----dfbpanel, fig.width=5, fig.height=5, fig.align='center'-------------
+## ----dfbpanel, fig.width=7, fig.height=7, fig.align='center'-------------
 model <- lm(mpg ~ disp + hp + wt, data = mtcars)
-ols_dfbetas_panel(model)
+ols_plot_dfbetas(model)
 
 ## ----rfsplot, fig.width=10, fig.height=5, fig.align='center'-------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-ols_rfs_plot(model)
+ols_plot_resid_fit_spread(model)
 
 ## ----bp1-----------------------------------------------------------------
 model <- lm(mpg ~ disp + hp + wt + drat, data = mtcars)
-ols_bp_test(model)
+ols_test_breusch_pagan(model)
 
 ## ----colldiag------------------------------------------------------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
@@ -34,24 +34,21 @@ ols_coll_diag(model)
 ## ----stepwise1-----------------------------------------------------------
 # stepwise regression
 model <- lm(y ~ ., data = surgical)
-ols_stepwise(model)
+ols_step_both_p(model)
 
 ## ----stepwise2, fig.width=10, fig.height=15, fig.align='center'----------
 model <- lm(y ~ ., data = surgical)
-k <- ols_stepwise(model)
+k <- ols_step_both_p(model)
 plot(k)
 
 ## ----stepaicb1-----------------------------------------------------------
 # stepwise aic backward regression
 model <- lm(y ~ ., data = surgical)
-k <- ols_stepaic_backward(model)
+k <- ols_step_backward_aic(model)
 k
 
-### Plot
-
-
 ## ----stepaicb2, fig.width=5, fig.height=5, fig.align='center'------------
 model <- lm(y ~ ., data = surgical)
-k <- ols_stepaic_backward(model)
+k <- ols_step_backward_aic(model)
 plot(k)
 
