@@ -1,7 +1,6 @@
-context('normality test output')
-
-test_that('output from normality test is as expected', {
+context("normality test output")
 
+test_that("output from normality test is as expected", {
   x <- cat("-----------------------------------------------
        Test             Statistic       pvalue
 -----------------------------------------------
@@ -13,13 +12,10 @@ Anderson-Darling          0.5859         0.1188
 
 
   model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-  expect_equivalent(print(ols_norm_test(model)), x)
-
+  expect_output(print(ols_test_normality(model)), x)
 })
 
-test_that('output from ols_corr_test is as expected', {
-
+test_that("output from ols_corr_test is as expected", {
   model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-  expect_equal(round(ols_corr_test(model), 3), 0.97)
-
+  expect_equal(round(ols_test_correlation(model), 3), 0.97)
 })
